@@ -4,11 +4,14 @@ sub Mojo::Webqq::Client::_recv_message{
     my $api_url = ($self->security?'https':'http') . '://d.web2.qq.com/channel/poll2';
     my $callback = sub {
         my ($json,$ua,$tx) = @_;
-        #分析接收到的消息，并把分析后的消息放到接收消息队列中
-        if(defined $json){
-            $self->parse_receive_msg($json);
-            $self->emit(receive_raw_message=>$tx->res->body,$json);
-        }
+        eval{
+            #分析接收到的消息，并把分析后的消息放到接收消息队列中
+            if(defined $json){
+                $self->parse_receive_msg($json);
+                $self->emit(receive_raw_message=>$tx->res->body,$json);
+            }
+        };
+        $self->error($@) if $@;
         #重新开始接收消息
         $self->emit("poll_over");
     };
